#
#  FILE NAME:
#      enum_converter.py
#
#  AUTHOR(S):
#      Dariusz Walczak <dariusz.walczak@gmail.com>
#

# Standard library imports:
import logging
import re

# P3 imports:
from p3.base import Enum, safe_fmt
from p3.logic.var.converter.conversion_result import ConversionResult

_LOG = logging.getLogger( "p3.logic" )


class EnumConverter( object ):
    errors = Enum( "format_error", "empty_input", "value_error" )

    ## ===[ Initialization ]==================================================================== ##

    def __init__( self, enum ):
        self.enum = enum


    ## ===[ Conversion ]======================================================================== ##

    def deserialize( self, value ):
        if not isinstance( value, basestring ):
            raise TypeError( safe_fmt( "EnumConverter.deserialize method expects basestring as its"
                                       " parameter (got %s instead).", type(value) ) )

        res = ConversionResult( value, self.__class__ )

        if not value:
            res.errors.append( self.errors.empty_input )
            return res

        m = re.match( "^-{0,1}[1-9]{1}[0-9]*$|^0$", value )

        if m is not None:
            out_val = int(m.group(0))

            if out_val in self.enum:
                res.out_val = out_val
            else:
                res.errors.append( self.errors.value_error )
        else:
            res.errors.append( self.errors.format_error )

        return res
