#
#  FILE NAME:
#      shared_database_suite.py
#
#  AUTHOR(S):
#      Dariusz Walczak <dariusz.walczak@gmail.com>
#

# Standard library imports:
import logging
import unittest

# P3 imports:
from p3.db import DbConnection
from p3.db.manage import create_db, drop_db


_LOG = logging.getLogger( "p3.test" )


class SharedDatabaseSuite( unittest.TestSuite ):
    ## \param mng_db_spec standard database connection specification used for database creation.
    #  \param tst_db_spec standard database connection specification used the test database
    #         creation and connection.
    def __init__( self, mng_db_spec, tst_db_spec ):
        super( SharedDatabaseSuite, self ).__init__()
        self.mng_db_spec = mng_db_spec
        self.tst_db_spec = tst_db_spec

    def run( self, result ):
        dbc = DbConnection.create_from_dict( self.mng_db_spec )
        db_name = self.tst_db_spec['name']

        create_db( dbc, db_name, True )
        super( SharedDatabaseSuite, self ).run( result )
        drop_db( dbc, db_name )
